@@ -6,8 +6,9 @@ This is a big wrapper class for most of the KIPET methods
 # Standard library imports
 import collections
 import copy
+import os
 import pathlib
-import weakref
+import sys
 
 # Third party imports
 import numpy as np
@@ -111,6 +112,7 @@ class ReactionModel(WavelengthSelectionMixins):
         self._var_to_fix_from_trajectory = []
         self._var_to_initialize_from_trajectory = []
         self._default_time_unit = 'seconds'
+        self.unit_base = kwargs.get('unit_base', None)
         
         self._G_data = {'G_contribution': None, 'Z_in': dict(), 'St': dict()}
         self.__var = VariableNames()
@@ -240,7 +242,7 @@ class ReactionModel(WavelengthSelectionMixins):
         """Create a algebraic variable with a localized pyomo var
         
         """
-        raise Warning('This is deprecated and will be removed in a future version')
+        print('Warning: This is deprecated and will be removed in a future version')
         
         return self._add_model_component('algebraic', 
                                         2, 
@@ -336,17 +338,25 @@ class ReactionModel(WavelengthSelectionMixins):
     def add_data(self, *args, **kwargs):
         
         name = kwargs.get('name', None)
+        time_scale = kwargs.get('time_scale', self.unit_base.TIME_BASE)
+        
+        time_conversion = 1
+        if time_scale != self.unit_base.TIME_BASE:
+            time_conversion = self.ub.ur(time_scale).to(self.unit_base.TIME_BASE).m
+        
         if len(args) > 0:
             name = args[0]
         if name is None:
             name = f'ds{len(self.data) + 1}'
+            
         filename = kwargs.get('file', None)
         data = kwargs.pop('data', None)
         category = kwargs.pop('category', None)
         remove_negatives = kwargs.get('remove_negatives', False)
     
         if filename is not None:
-            filename = _set_directory(self, filename)
+            calling_file_name = os.path.dirname(os.path.realpath(sys.argv[0]))
+            filename = pathlib.Path(calling_file_name).joinpath(filename)
             kwargs['file'] = filename
             dataframe = data_tools.read_file(filename)
         elif filename is None and data is not None:
@@ -354,6 +364,7 @@ class ReactionModel(WavelengthSelectionMixins):
         else:
             raise ValueError('User must provide filename or dataframe')
         
+        dataframe.index = dataframe.index*time_conversion
         
         if category == 'spectral':
             D_data = SpectralData(name, remove_negatives=remove_negatives)    
@@ -1077,7 +1088,6 @@ class ReactionModel(WavelengthSelectionMixins):
                 try:
                     comp.variance = self.variances[comp.name]
                 except:
-                    print(f'No variance information for {comp.name} found, setting equal to unity')
                     comp.variance = 1
                 
         # Create ParameterEstimator
@@ -1319,7 +1329,7 @@ class ReactionModel(WavelengthSelectionMixins):
         # parameter_dict = self.parameters.as_dict(bounds=True)
         results, reduced_model = rhps_method(self.model, **kwargs)
         
-        results.file_dir = self.settings.general.charts_directory
+#        results.file_dir = self.settings.general.charts_directory
         
         self.reduced_model = reduced_model
         self.using_reduced_model = True
@@ -1435,18 +1445,6 @@ class ReactionModel(WavelengthSelectionMixins):
         
     """MODEL FUNCTION AREA"""
     
-    # def step(self, *args, **kwargs):
-    #     """Wrapper for the step_fun in model_funs module
-        
-    #     """
-    #     return step_fun(*args, **kwargs)
-    
-    # def step_var(self, *args, **kwargs):
-    #     """Wrapper for the step_fun in model_funs module
-        
-    #     """
-    #     return step_fun_var_time(*args, **kwargs)
-    
     def make_reaction_table(self, stoich_coeff, rxns):
         
         df = pd.DataFrame()
@@ -1506,6 +1504,11 @@ class ReactionModel(WavelengthSelectionMixins):
 
 
     def check_component_units(self):
+        """Method to check whether the units provided are consisten with the
+        base units
+        
+        """
+        print('Checking model component units:\n')
         
         element_dict = {
            'parameters': self.parameters,
@@ -1520,11 +1523,16 @@ class ReactionModel(WavelengthSelectionMixins):
                 comp._check_scaling()
         
         self._units_checked = True
+        print('')
         
         return None
 
     def check_model_units(self, display=False):
-
+        """Method to check the expected units of the algebraic and odes
+        
+        """
+        print('Checking expected equation units:\n')
+        
         if not self.__flag_odes_built:
             self._build_odes()
         if not self.__flag_algs_built:
@@ -1543,25 +1551,27 @@ class ReactionModel(WavelengthSelectionMixins):
         self.c_units = get_unit_model(element_dict, self._set_up_model)
         
         for key, expr in self.algs_dict.items():
-            expr.check_units2(self.c, self.c_units)
+            expr.check_units(self.c, self.c_units)
         for key, expr in self.odes_dict.items():
-            expr.check_units2(self.c, self.c_units)
+            expr.check_units(self.c, self.c_units)
         
         if display:
             self.ode_obj.display_units()
             print('')
-            self.alg_obj.display_units()
+            if len(self.alg_obj) > 0:
+                self.alg_obj.display_units()
+                print('')
             
         return None
     
     
-    def plot(self, var=None):
+    def plot(self, var=None, jupyter=False):
         
         """Plot results using the variable or variable class"""
         
         from kipet.visuals.plots import PlotObject
         
-        self._plot_object = PlotObject(self)
+        self._plot_object = PlotObject(reaction_model=self, jupyter=jupyter)
         
         if var == 'Z':
             self._plot_object._plot_all_Z()
